#
# spec file for package tpm2-0-tss
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tpm2-0-tss
Version:        1.3.0
Release:        lp150.1.2
Summary:        Intel's TCG Software Stack access libraries for TPM 2.0 chips
License:        BSD-2-Clause
Group:          Productivity/Security
Url:            https://github.com/tpm2-software/tpm2-tss
Source0:        https://github.com/tpm2-software/tpm2-tss/archive/%{version}.tar.gz
Source2:        baselibs.conf
Patch0:         version_fix.patch
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The tpm2-0-tss package provides a TPM 2.0 TSS implementation. This
implementation is developed by INTEL. This package contains the libraries,
see the tpm2.0-abrmd package for the resource manager daemon, tpm2.0-tools for
utilities.

%package devel
Summary:        Development headers for the Intel TSS library for TPM 2.0 chips
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsapi0 = %{version}
Requires:       libtcti-device0 = %{version}
Requires:       libtcti-socket0 = %{version}
Requires:       tpm2-0-tss = %{version}

%description devel
This package provides the development files for the libsapi library
for accessing TPM 2.0 chips.

%package -n libsapi0
Summary:        TPM2 System API library
# Non-SLPP package name from earlier
Group:          System/Libraries
Obsoletes:      libtss2 < %version-%release
Provides:       libtss2 = %version-%release

%description -n libsapi0
This package provides the library to access the TSS (TCG Software Stack) for
accessing TPM 2.0 chips.

%package -n libtcti-device0
Summary:        TCTI library for communicating with a TPM device node
Group:          System/Libraries

%description -n libtcti-device0
TPM Command Transmission Interface library for communicating with a
TPM device node.

%package -n libtcti-socket0
Summary:        TCTI library for communicating with a TPM over a socket
Group:          System/Libraries

%description -n libtcti-socket0
TPM Command Transmission Interface library for communicating with a
TPM over a socket.

%prep
%setup -q -n tpm2-tss-%{version}
# TODO: XX:
# this fixes the autoconf version number which is determined via git and
# doesn't work in OBS. The distribution tarball may fix this in the future for
# us. If we don'T do this then the pkg-config *.pc files don't contain a
# version number and dependent packages like tpm2.0-tools fail to build.
#
# the version number needs to be fixed with each version change!
%patch0 -p1

%build
# we are still using the source tarball here. there is a release tarball for
# 1.3.0, but some files like README and CHANGELOG are missing there. The next
# release should work for us.
bash bootstrap
%configure --disable-static
make %{?_smp_mflags} PTHREAD_LDFLAGS=-pthread

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libsapi0 -p /sbin/ldconfig
%postun -n libsapi0 -p /sbin/ldconfig
%post -n libtcti-device0 -p /sbin/ldconfig
%postun -n libtcti-device0 -p /sbin/ldconfig
%post -n libtcti-socket0 -p /sbin/ldconfig
%postun -n libtcti-socket0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc *.md LICENSE
%{_mandir}/man3/*
%{_mandir}/man7/tcti-*

%files devel
%defattr(-,root,root)
%{_includedir}/tcti
%{_includedir}/sapi
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files -n libsapi0
%defattr(-,root,root)
%{_libdir}/libsapi.so.*

%files -n libtcti-device0
%defattr(-,root,root)
%{_libdir}/libtcti-device.so.*

%files -n libtcti-socket0
%defattr(-,root,root)
%{_libdir}/libtcti-socket.so.*

%changelog
* Wed Mar  7 2018 matthias.gerstner@suse.com
- removed leftover comment from dropped reproducable.patch
* Thu Feb 22 2018 matthias.gerstner@suse.com
- update to upstream version 1.3.0:
  - support for reproducable builds
  - improved documentation / manual pages
  - various stability bugfixes
  - EncryptDecrypt2 command is now implemented
- removed reproducible.patch. This is now included upstream.
- added version_fix.patch to fix package config version numbers.
* Fri Sep  1 2017 matthias.gerstner@suse.com
- fix the "fix", turns out only the unversioned symlink's supposed to go into
  - devel.
* Thu Jul 20 2017 matthias.gerstner@suse.com
- no longer install the udev rule, it's now part of the new tpm2.0-abrmd
  package.
- fixed a warning regarding a missing dependency of the devel package to the
  main package
- correctly package library symlinks only in the devel package, the library
  itself only in the library package. Was mixed up before.
* Wed Jul 19 2017 matthias.gerstner@suse.com
- removed tpm2-0-tss-configure.patch, it was just a hack, fixed by requiring
  autoconf-archive, see https://github.com/01org/TPM2.0-TSS/issues/227.
* Wed Jul 19 2017 matthias.gerstner@suse.com
- Updated to upstream version 1.1.0
  - With this version the resourcemgr daemon is dropped from this package. It
    is replaced by a completely new implementation found in a new package
    tpm2.0-abrmd. this package will only consist of the libraries any more.
  - Changed
  - tpmclient, disabled all tests that rely on the old resourcemgr.
  - Fixed
  - Fixed definition of PCR_LAST AND TRANSIENT_LAST macros.
  - Removed
  - tpmtest
  - resourcemgr, replacement is in new repo: https://github.com/01org/tpm2-abrmd
* Sat May 27 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Thu May 11 2017 matthias.gerstner@suse.com
- create tss user account and install udev rule to fix startup of resourcemgr
  (bnc#1038586)
* Wed May 10 2017 mgerstner@suse.com
- remove unnecessary dependency of libsapi0 to trousers. trousers has nothing
  to do with tpm2-tss.
* Tue Apr 11 2017 meissner@suse.com
- fixed typo in resourcemgr.service (bsc#1031004)
* Thu Feb 16 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs.
- Fix an improper Requires line.
- Split libtcti* from libsapi0; these are independentlty
  developable units.
* Wed Feb  8 2017 meissner@suse.com
- Updated to 1.0 (FATE#321508)
  - Added
  - Travis-CI integration with GitHub
  - Unit tests for primitive (un)?marshal functions.
  - Example systemd unit for resourcemgr.
  - Allow for unit tests to be enabled selectively.
  - added pkg-config files for libraries
  - Changed
  - move simulator initialization code to socket TCTI init function.
  - socket TCTI finalize no longer frees context
  - rename libtss2 to libsapi
  - rename libtcti_device to libtcti-device
  - rename libtcti_socket to libtcti-socket
  - move $(includedir)/tss to $(includedir)/sapi
  - Move default compiler flags to config.site file.
  - Fixed
  - Fix run away resourcemgr threads by closing client sockets when resourcemgr recv() call returns 0.
  - Set MSG_NOSIGNAL for client connections to avoid SIGPIPE killing resourcemgr.
  - Fixes to handling of persistent objects by resourcemgr.
  - Removed
  - Semicolon from TPMA_* macros definitions.
  - Windows build files.
  - SAPI_CLIENT macro tests.
  - Security
  - Fix buffer overflow in resourcemgr.
- use sample resourcemanager.service
- tpm2-0-tss-configure.patch: fix weird error.
* Thu Aug 25 2016 meissner@suse.com
- Remove type=forking from service file (bsc#995554)
* Sat Aug  6 2016 meissner@suse.com
- added a systemd unit service file (FATE#315631)
* Fri May  6 2016 jengelh@inai.de
- Correct package naming to be in line with shared library guideline
- Remove unused systemd build and runtime dependencies
  (FATE#315631)
* Fri Apr  8 2016 dimstar@opensuse.org
- Fix rpm group of library package: libs belong, per definition, to
  the group "System/Libraries". (FATE#315631)
* Wed Feb 24 2016 meissner@suse.com
- initial import of the tpm 2.0 tss stack (FATE#315631)
